@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2008 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.cc,v 1.151 2007/11/03 15:08:13 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.154 2008/01/21 14:06:59 lav Exp $ */
 
 #include <config.h>
 
@@ -29,6 +29,7 @@
 #include <errno.h>
 #include <ctype.h>
 #include <assert.h>
+#include <stddef.h>
 #include "ascii_ctype.h"
 #include <fcntl.h>
 #include "LsCache.h"
@@ -104,36 +105,35 @@ FileAccess::~FileAccess()
    ListDel(FileAccess,chain,this,next);
 }
 
-void  FileAccess::Log2(int level,const char *str0)
+void  FileAccess::Log2(int level,xstring& str)
 {
-   xstring &str=xstring::get_tmp();
-   str.set(str0);
    str.chomp('\n');
    str.chomp('\r');
    str.append('\n');
    Log::global->Write(level,str);
 }
-void  FileAccess::Log3(int level,const char *prefix,const char *str)
+void  FileAccess::Log3(int level,const char *prefix,const char *str0)
 {
-   Log::global->Write(level,prefix);
+   xstring &str=xstring::get_tmp(prefix);
+   str.append(str0);
    Log2(level,str);
 }
 void FileAccess::LogError(int level,const char *fmt,...)
 {
    va_list v;
    va_start(v,fmt);
-   Log::global->Write(level,"**** ");
-   Log::global->vFormat(level,fmt,v);
-   Log::global->Write(level,"\n");
+   xstring &str=xstring::get_tmp("**** ");
+   str.vappendf(fmt,v);
+   Log2(level,str);
    va_end(v);
 }
 void FileAccess::LogNote(int level,const char *fmt,...)
 {
    va_list v;
    va_start(v,fmt);
-   Log::global->Write(level,"---- ");
-   Log::global->vFormat(level,fmt,v);
-   Log::global->Write(level,"\n");
+   xstring &str=xstring::get_tmp("---- ");
+   str.vappendf(fmt,v);
+   Log2(level,str);
    va_end(v);
 }
 void FileAccess::LogRecv(int level,const char *line)
